package
Version:
v1.4.2
Opens a new window with list of versions in this module.
Published: Nov 14, 2025
License: MIT
Opens a new window with license information.
Imports: 6
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Execute adds all child commands to the root command
type Config struct {
Database struct {
Driver string `yaml:"driver"`
DSN string `yaml:"dsn"`
Name string `yaml:"name"`
} `yaml:"database"`
HTTP struct {
Engine string `yaml:"engine"`
Port int `yaml:"port"`
} `yaml:"http"`
Auth struct {
Secret string `yaml:"secret"`
} `yaml:"auth"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.